# wickedhot
Wicked easy one-hot-encoder in pure python with no dependencies

Properties

* Built for streaming
* Easy configuration of maximum number of levels
* Simple handling of unseen categorical levels
* Unobtrusive handling of numerical values
* Built in serialization and persistence of encoder
* Well tested
